@@ -1,6 +1,6 @@
 `getSolution` <-
-function(expressions, collapse, uplow, use.tilde, inputt, row.dom, initial, min.dis) {
-        
+function(expressions, collapse, uplow, use.tilde, inputt, row.dom, initial, all.sol, ...) {
+    
     PI <- writePrimeimp(expressions, collapse=collapse, uplow=uplow, use.tilde=use.tilde)
     rownames(expressions) <- PI
     
@@ -10,7 +10,7 @@ function(expressions, collapse, uplow, use.tilde, inputt, row.dom, initial, min.
     rownames(expressions) <- PI.sort
     
      # create the prime implicants chart
-    mtrx <- createChart(expressions, inputt)
+    mtrx <- QCAGUI::makeChart(expressions, inputt)
     
     reduced <- list(expressions = expressions, mtrx = mtrx)
     
@@ -30,15 +30,7 @@ function(expressions, collapse, uplow, use.tilde, inputt, row.dom, initial, min.
     rownames(mtrx) <- PI.red.sort
     colnames(mtrx) <- initial
     
-    # other.args <- list(...)
-    # if ("bla" %in% names(other.args)) {
-        # return(list(mtrx=mtrx, min.dis=min.dis))
-        # return(list(RE=reduced$expressions, AP = all.PIs))
-        # print(sortVector(rownames(reduced$expressions)[rownames(reduced$expressions) %in% all.PIs], collapse=collapse))
-        
-    # }
-    
-    sol.matrix <- solveChart(mtrx, min.dis = min.dis)
+    sol.matrix <- solveChart(mtrx, all.sol=all.sol, ...=...)
     
     sol.matrix <- matrix(rownames(mtrx)[sol.matrix], nrow=nrow(sol.matrix))
     
