@@ -3,13 +3,10 @@
 # include <R_ext/Rdynload.h>
 # include <stdlib.h>
 
-
 SEXP findSubsets(SEXP rowno, SEXP noflevels, SEXP mbase, SEXP max) {
     int *prowno, *pnoflevels, *pmbase, *pmax, lmbase, lmbasei, i, j, k, lungime, flag, templung, *ptemp1, *ptemp2;
     SEXP temp1, temp2;
     
-    
-    
     SEXP usage = PROTECT(allocVector(VECSXP, 6));
     
     SET_VECTOR_ELT(usage, 0, rowno = coerceVector(rowno, INTSXP));
@@ -39,18 +36,13 @@ SEXP findSubsets(SEXP rowno, SEXP noflevels, SEXP mbase, SEXP max) {
     
     templung = 1;
     
-    
-    //Rprintf("length(mbase): %d\n", length(mbase));
-    
     for (i = 0; i < lmbase; i++) {
         lmbasei = lmbase - i - 1;
-        //Rprintf("rowno: %d; mbase.val: %d; noflevels.i: %d\n", prowno[0], pmbase[i], pnoflevels[i] + 1);
-        //Rprintf("%d d/d %d = %d\n", prowno[0] - 1, pmbase[i], div(prowno[0] - 1, pmbase[i]).quot);
-        //Rprintf("%d dd %d = %d\n", div(prowno[0] - 1, pmbase[i]).quot, pmbase[i], div(div(prowno[0] - 1, pmbase[i]).quot, pnoflevels[i] + 1).rem);
+        
         if (div(div(prowno[0] - 1, pmbase[lmbasei]).quot, pnoflevels[lmbasei] + 1).rem == 0) {
             flag = 1;
             lungime = templung * (pnoflevels[lmbasei] + 1);
-            //Rprintf("lungime: %d\n", lungime);
+            
             SET_VECTOR_ELT(usage, 5, temp2 = allocVector(INTSXP, lungime));
             ptemp2 = INTEGER(temp2);
             
@@ -73,22 +65,18 @@ SEXP findSubsets(SEXP rowno, SEXP noflevels, SEXP mbase, SEXP max) {
         }
     }
     
-    //Rprintf("lungime: %d; templung: %d\n\n", lungime, templung);
-    
     if (flag == 1) {
     
         templung = 0;
         
         for (i = 0; i < lungime; i++) {
-            //Rprintf("%d ", ptemp2[i]);
+            
             if (ptemp2[i] < (pmax[0] + 1)) {
                 templung += 1;
             }
         }
         
-        //Rprintf("lungime: %d; templung: %d; i: %d\n", lungime, templung, i);
-        
-        SET_VECTOR_ELT(usage, 4, temp1 = allocVector(INTSXP, templung - 1)); //"- 1" because the first element needs to be eliminated as well
+        SET_VECTOR_ELT(usage, 4, temp1 = allocVector(INTSXP, templung - 1)); 
         ptemp1 = INTEGER(temp1);
         
         j = 0;
