@@ -20,8 +20,6 @@ SEXP removeRedundants(SEXP rowno, SEXP noflevels, SEXP mbase) {
     lmbase = length(mbase);
     lrowno = length(rowno);
     
-    
-    // create the vector of next positions (similar to linked lists)
 	SET_VECTOR_ELT(usage, 3, next = allocVector(INTSXP, lrowno));
 	pointer_next = INTEGER(next);
 	
@@ -29,7 +27,6 @@ SEXP removeRedundants(SEXP rowno, SEXP noflevels, SEXP mbase) {
 	    pointer_next[i] = i + 1;
 	}
 	
-    
 	rn = 0;
 	flag1 = 0;
 	
@@ -41,7 +38,6 @@ SEXP removeRedundants(SEXP rowno, SEXP noflevels, SEXP mbase) {
         pointer_temp1 = INTEGER(temp1);
         pointer_temp1[0] = pointer_rowno[rn];
         
-        
         flag2 = 0;
             
         for (i = 0; i < lmbase; i++) {
@@ -72,7 +68,7 @@ SEXP removeRedundants(SEXP rowno, SEXP noflevels, SEXP mbase) {
             }
         }
         
-        if (flag2 == 1) { // the current row number has subsets, stored in temp2
+        if (flag2 == 1) { 
             ltemp2 = length(temp2);
             
             i = pointer_next[previous];
@@ -85,7 +81,7 @@ SEXP removeRedundants(SEXP rowno, SEXP noflevels, SEXP mbase) {
                 else if (pointer_rowno[i] > pointer_temp2[j]) {
                     j++;
                 }
-                else { // if (pointer_rowno[i] == pointer_temp2[j])
+                else { 
                     flag1 = 1;
                     pointer_next[previous] = pointer_next[i];
                     i = pointer_next[i];
@@ -97,8 +93,7 @@ SEXP removeRedundants(SEXP rowno, SEXP noflevels, SEXP mbase) {
 		rn = pointer_next[rn];
     }
         
-    
-    if (flag1 == 0) { // no single row has been found redundant
+    if (flag1 == 0) { 
         UNPROTECT(1);
         return(rowno);
     }
